declare const __parsed_brand: unique symbol;
export type Brand<T, B> = T & {
    [__parsed_brand]: B;
};
export type Parser<T> = (value: unknown) => T;
export declare class ParseError extends Error {
    name: string;
    shape: string;
    path: string;
    constructor(message: string, shape?: string, path?: string);
}
export declare const Parse: {
    readonly unknown: (val: unknown) => unknown;
    readonly number: (val: unknown) => number;
    readonly string: (val: unknown) => string;
    readonly boolean: (val: unknown) => boolean;
    readonly bigint: (val: unknown) => bigint;
    readonly symbol: (val: unknown) => symbol;
    readonly null: (val: unknown) => null;
    readonly undefined: (val: unknown) => undefined;
    readonly literal: <T extends string | number | boolean | bigint | symbol | null | undefined>(literal: T) => (val: unknown) => T;
    readonly int: (val: unknown) => number;
    readonly nan: (val: unknown) => number;
    readonly instanceOf: <T>(classDef: {
        new (): T;
    }) => (val: unknown) => T;
    readonly arrayOf: <T>(parser: (val: unknown) => T, shapeName?: string) => (val: unknown) => T[];
    readonly shape: <T extends Record<string, Parser<any>>>(parsers: T, shapeName?: string) => (val: unknown) => { [K in keyof T]: ReturnType<T[K]>; };
    readonly regex: <T extends string>(regex: RegExp, shapeName?: string) => (val: unknown) => T;
    readonly enum: <E extends string>(enumDef: readonly E[], shapeName?: string) => (val: unknown) => E;
    readonly optional: <T>(parser: (val: unknown) => T) => (val: unknown) => T | undefined;
    readonly nullable: <T>(parser: (val: unknown) => T) => (val: unknown) => T | null;
    readonly oneOf: <T extends Parser<unknown>[]>(parsers: T, shapeName?: string) => (value: unknown) => ReturnType<T[number]>;
};
export {};
